searchData={"content_type":"text/markdown","items":[{"doc":"This module provides a function to convert a JSONPath expression into an access path.\nThis library does not support all of jsonpath:\n\n- the `..` operator is not supported because it can't be expressed using Access functions (that I know of)\n- all the functions like length for the same reason as above\n\nThere are two main methods:\n\n- `convert/2` and `get_in/2`\n\nConvert the JSONPath expression into an access path. This function is used by the `get_in/2` function.\nYou have to specify upfront if the data contains atom keys or not.\nYou can cache or put the convert in a module attribute.\n\n```elixir\niex> path = JsonpathToAccess.convert!(\"$.store.book[0].author\", to_atoms: true)\niex> JsonpathToAccess.get_in(%{store: %{book: [%{author: \"Gandalf\"}]}}, path)\n\"Gandalf\"\n```\n\n```elixir\ndefmodule MyModule do\n  @json_path JsonpathToAccess.convert!(\"$.store.book[0].author\")\n\n  def my_lookup(data) do\n    # or you can use the normal get_in if you don't use absolute path filter.\n    JsonpathToAccess.get_in(data, @json_path)\n  end\nend\n```\n\n- `lookup/2`\n\nJust lookup the value in a map using the JSONPath expression.\n\n```elixir\niex> JsonpathToAccess.lookup(%{store: %{book: [%{author: \"Gandalf\"}]}}, \"$.store.book[0].author\")\n{:ok, \"Gandalf\"}\n```","ref":"JsonpathToAccess.html","title":"JsonpathToAccess","type":"module"},{"doc":"Converts a JSONPath into an Access path.\nThis can be used later with the `JsonpathToAccess.get_in/2` function.\n\n```elixir\niex> {:ok, access_path} = JsonpathToAccess.convert(\"$.a.b\")\niex> JsonpathToAccess.get_in(%{\"a\" => %{\"b\" => \"value\"}}, access_path)\n\"value\"\niex> {:ok, access_path} = JsonpathToAccess.convert(\"$.a.b\", to_atoms: true)\niex> JsonpathToAccess.get_in(%{a: %{b: \"value\"}}, access_path)\n\"value\"\n```","ref":"JsonpathToAccess.html#convert/2","title":"JsonpathToAccess.convert/2","type":"function"},{"doc":"Converts a JSONPath into an Access path.\nThis can be used later with the `JsonpathToAccess.get_in/2` function.\n\n```elixir\niex> access_path = JsonpathToAccess.convert!(\"$.a.b\")\niex> JsonpathToAccess.get_in(%{\"a\" => %{\"b\" => \"value\"}}, access_path)\n\"value\"\niex> access_path = JsonpathToAccess.convert!(\"$.a.b\", to_atoms: true)\niex> JsonpathToAccess.get_in(%{a: %{b: \"value\"}}, access_path)\n\"value\"\n```","ref":"JsonpathToAccess.html#convert!/2","title":"JsonpathToAccess.convert!/2","type":"function"},{"doc":"The missing `fetch_in` function from `Kernel`.\n\nProbably not exactly what you want, internally used for looking up if a value exists in a nested map.","ref":"JsonpathToAccess.html#fetch_in/2","title":"JsonpathToAccess.fetch_in/2","type":"function"},{"doc":"Similar to `Kernel.get_in/2`, but it resolves the absolute values.","ref":"JsonpathToAccess.html#get_in/2","title":"JsonpathToAccess.get_in/2","type":"function"},{"doc":"Looks up data using a JSONPath.\n\n```elixir\niex> JsonpathToAccess.lookup(%{\"a\" => %{\"b\" => 1}}, \"$.a.b\")\n{:ok, 1}\niex> JsonpathToAccess.lookup(%{a: %{b: 1}}, \"$.a.b\")\n{:ok, 1}\niex> JsonpathToAccess.lookup([a: [[b: 1], [b: 2], [b: 3]]], \"$.a[?(@.b >= 2)].b\")\n{:ok, [2, 3]}\n```","ref":"JsonpathToAccess.html#lookup/2","title":"JsonpathToAccess.lookup/2","type":"function"},{"doc":"","ref":"JsonpathToAccess.html#t:access_path/0","title":"JsonpathToAccess.access_path/0","type":"type"},{"doc":"","ref":"JsonpathToAccess.html#t:operator/0","title":"JsonpathToAccess.operator/0","type":"type"},{"doc":"","ref":"JsonpathToAccess.html#t:options/0","title":"JsonpathToAccess.options/0","type":"type"},{"doc":"This module is responsible for formatting the AST into a string that can be used to access the JSON data.","ref":"JsonpathToAccess.Formatter.html","title":"JsonpathToAccess.Formatter","type":"module"},{"doc":"","ref":"JsonpathToAccess.Formatter.html#format/2","title":"JsonpathToAccess.Formatter.format/2","type":"function"},{"doc":"","ref":"JsonpathToAccess.Formatter.html#format_to_iolist/2","title":"JsonpathToAccess.Formatter.format_to_iolist/2","type":"function"},{"doc":"","ref":"JsonpathToAccess.Formatter.html#t:tree/0","title":"JsonpathToAccess.Formatter.tree/0","type":"type"},{"doc":"Implements a parser for JSONPath expressions.","ref":"JsonpathToAccess.Parser.html","title":"JsonpathToAccess.Parser","type":"module"},{"doc":"","ref":"JsonpathToAccess.Parser.html#dotnotation_expr/1","title":"JsonpathToAccess.Parser.dotnotation_expr/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#identifier/1","title":"JsonpathToAccess.Parser.identifier/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#inner_query/1","title":"JsonpathToAccess.Parser.inner_query/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#just_absolute_path/1","title":"JsonpathToAccess.Parser.just_absolute_path/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#natural_number/1","title":"JsonpathToAccess.Parser.natural_number/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#parse/1","title":"JsonpathToAccess.Parser.parse/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#parser/0","title":"JsonpathToAccess.Parser.parser/0","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#qualifier/1","title":"JsonpathToAccess.Parser.qualifier/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#query_comparison/3","title":"JsonpathToAccess.Parser.query_comparison/3","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#query_contains/1","title":"JsonpathToAccess.Parser.query_contains/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#query_expr/1","title":"JsonpathToAccess.Parser.query_expr/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#query_not_contains/1","title":"JsonpathToAccess.Parser.query_not_contains/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#quoted_identifier/1","title":"JsonpathToAccess.Parser.quoted_identifier/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#relative_path/1","title":"JsonpathToAccess.Parser.relative_path/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#root/0","title":"JsonpathToAccess.Parser.root/0","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#select_all_index/1","title":"JsonpathToAccess.Parser.select_all_index/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#select_multi_index/1","title":"JsonpathToAccess.Parser.select_multi_index/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#select_range_index/1","title":"JsonpathToAccess.Parser.select_range_index/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#select_single_index/1","title":"JsonpathToAccess.Parser.select_single_index/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#string_literal/1","title":"JsonpathToAccess.Parser.string_literal/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#tagged_identifier/1","title":"JsonpathToAccess.Parser.tagged_identifier/1","type":"function"},{"doc":"","ref":"JsonpathToAccess.Parser.html#value_literal/1","title":"JsonpathToAccess.Parser.value_literal/1","type":"function"},{"doc":"Normal Elixir comparisions can compare different types, this module implements the comparisions only if the types are the same.\nOtherwise they are false.\n\nDon't use these functions for sorting, because this will return unexpected results.","ref":"JsonpathToAccess.SafeComparisions.html","title":"JsonpathToAccess.SafeComparisions","type":"module"},{"doc":"","ref":"JsonpathToAccess.SafeComparisions.html#!=/2","title":"JsonpathToAccess.SafeComparisions.!=/2","type":"function"},{"doc":"","ref":"JsonpathToAccess.SafeComparisions.html#%3C/2","title":"JsonpathToAccess.SafeComparisions.</2","type":"function"},{"doc":"","ref":"JsonpathToAccess.SafeComparisions.html#%3C=/2","title":"JsonpathToAccess.SafeComparisions.<=/2","type":"function"},{"doc":"","ref":"JsonpathToAccess.SafeComparisions.html#==/2","title":"JsonpathToAccess.SafeComparisions.==/2","type":"function"},{"doc":"","ref":"JsonpathToAccess.SafeComparisions.html#%3E/2","title":"JsonpathToAccess.SafeComparisions.>/2","type":"function"},{"doc":"","ref":"JsonpathToAccess.SafeComparisions.html#%3E=/2","title":"JsonpathToAccess.SafeComparisions.>=/2","type":"function"},{"doc":"","ref":"JsonpathToAccess.SafeComparisions.html#is_same_type/2","title":"JsonpathToAccess.SafeComparisions.is_same_type/2","type":"macro"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}